@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Params;
 
-$WWW::Google::CustomSearch::Params::VERSION = '0.19';
+$WWW::Google::CustomSearch::Params::VERSION = '0.20';
 
 use 5.006;
 use strict; use warnings;
@@ -18,7 +18,7 @@ WWW::Google::CustomSearch::Params - Placeholders for parameters for WWW::Google:
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
@@ -221,7 +221,7 @@ L<https://github.com/Manwar/WWW-Google-CustomSearch>
 
 =head1 CONTRIBUTORS
 
-David-Kitcher Jones (m4ddav3)
+David Kitcher-Jones (m4ddav3)
 
 =head1 BUGS
 
