@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Request;
 
-$WWW::Google::CustomSearch::Request::VERSION = '0.19';
+$WWW::Google::CustomSearch::Request::VERSION = '0.20';
 
 use 5.006;
 use Data::Dumper;
@@ -15,7 +15,7 @@ WWW::Google::CustomSearch::Request - Placeholder for Google JSON/Atom Custom Sea
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
@@ -68,7 +68,7 @@ L<https://github.com/Manwar/WWW-Google-CustomSearch>
 
 =head1 CONTRIBUTORS
 
-David-Kitcher Jones (m4ddav3)
+David Kitcher-Jones (m4ddav3)
 
 =head1 BUGS
 
